@@ -42,12 +42,13 @@ class BaseProxy(object):
     def _check_rebased(self):
         return self.url is not None
 
-    def _create_request_kwargs(self, data, headers=None, cookies=None, files=None):
+    def _create_request_kwargs(self, data, params=None, headers=None, cookies=None, files=None):
         kwargs = {
             'data': data,
             'headers': headers,
             'cookies': cookies,
-            'files': files
+            'files': files,
+            'params': params,
         }
         if data is None or data == {}:
             kwargs.pop('data', None)
@@ -55,6 +56,8 @@ class BaseProxy(object):
             kwargs['data'] = json.dumps(kwargs['data'])
         if files is None:
             kwargs.pop('files', None)
+        if params is None:
+            kwargs.pop('params', None)
         if headers is None:
             kwargs['headers'] = {}
         kwargs['headers'].update(self.headers)
@@ -72,10 +75,10 @@ class BaseProxy(object):
         self.rebase_args = args
         self.rebase_kwargs.update(kwargs)
 
-    def _operation(self, url, data=None, headers=None,
+    def _operation(self, url, data=None, params=None, headers=None,
         cookies=None, files=None, fn=requests.get):
         self.validate()
-        _kwargs = self._create_request_kwargs(data, headers, cookies, files)
+        _kwargs = self._create_request_kwargs(data, params, headers, cookies, files)
         if self.debug > 0:
             print "{} {}".format(*[fn.func_name.upper(), url])
         if self.debug > 1:
@@ -109,25 +112,25 @@ class BaseProxy(object):
     def flush_session(self):
         self.cookies = {}
 
-    def get(self, data=None, headers=None, cookies=None):
+    def get(self, data=None, params=None, headers=None, cookies=None):
         return self._operation(self.full_url(), fn=requests.get,
-            data=data, headers=headers, cookies=cookies)
+            data=data, params=params, headers=headers, cookies=cookies)
 
-    def post(self, data=None, headers=None, cookies=None, files=None):
+    def post(self, data=None, params=None, headers=None, cookies=None, files=None):
         return self._operation(self.full_url(), fn=requests.post,
-            data=data, headers=headers, cookies=cookies, files=files)
+            data=data, params=params, headers=headers, cookies=cookies, files=files)
 
-    def put(self, data=None, headers=None, cookies=None, files=None):
+    def put(self, data=None, params=None, headers=None, cookies=None, files=None):
         return self._operation(self.full_url(), fn=requests.put,
-            data=data, headers=headers, cookies=cookies, files=files)
+            data=data, params=params, headers=headers, cookies=cookies, files=files)
 
-    def patch(self, data=None, headers=None, cookies=None, files=None):
+    def patch(self, data=None, params=None, headers=None, cookies=None, files=None):
         return self._operation(self.full_url(), fn=requests.patch,
-            data=data, headers=headers, cookies=cookies, files=files)
+            data=data, params=params, headers=headers, cookies=cookies, files=files)
 
-    def delete(self, data=None, headers=None, cookies=None):
+    def delete(self, data=None, params=None, headers=None, cookies=None):
         return self._operation(self.full_url(), fn=requests.delete,
-            data=data, headers=headers, cookies=cookies)
+            data=data, params=params, headers=headers, cookies=cookies)
 
 
 class ResourceProxy(BaseProxy):
@@ -168,10 +171,10 @@ class ResourceProxy(BaseProxy):
             self.detail_url = ''
         return self
 
-    def list(self, data=None, headers=None, cookies=None):
+    def list(self, data=None, params=None, headers=None, cookies=None):
         return self._operation(self.full_list_url(), fn=requests.get,
-            data=data, headers=headers, cookies=cookies)
+            data=data, params=params, headers=headers, cookies=cookies)
 
-    def post(self, data=None, headers=None, cookies=None, files=None):
+    def post(self, data=None, params=None, headers=None, cookies=None, files=None):
         return self._operation(self.full_list_url(), fn=requests.post,
-            data=data, headers=headers, cookies=cookies, files=files)
+            data=data, params=params, headers=headers, cookies=cookies, files=files)
